@@ -5,6 +5,7 @@ import random
 import re
 import time
 from datetime import datetime, timezone
+from enum import Enum
 from http import HTTPStatus
 from typing import Any, Callable, Dict, List, Optional, Tuple, TypeVar, cast
 
@@ -138,7 +139,7 @@ def _encode_webhook_list_to_base64(webhooks: List[Dict]) -> bytes:
     data = []
     for webhook in webhooks:
         webhook_representation = {
-            'eventTypes': [event_type.value for event_type in webhook['event_types']],
+            'eventTypes': [_maybe_extract_enum_member_value(event_type) for event_type in webhook['event_types']],
             'requestUrl': webhook['request_url'],
         }
         if 'payload_template' in webhook:
@@ -198,11 +199,17 @@ def _encode_key_value_store_record_value(value: Any, content_type: Optional[str]
             content_type = 'application/json; charset=utf-8'
 
     if 'application/json' in content_type and not _is_file_or_bytes(value) and not isinstance(value, str):
-        value = json.dumps(value, ensure_ascii=False, indent=2).encode('utf-8')
+        value = json.dumps(value, ensure_ascii=False, indent=2, default=str).encode('utf-8')
 
     return (value, content_type)
 
 
+def _maybe_extract_enum_member_value(maybe_enum_member: Any) -> Any:
+    if isinstance(maybe_enum_member, Enum):
+        return maybe_enum_member.value
+    return maybe_enum_member
+
+
 class ListPage:
     """A single page of items returned from a list() method."""
 
@@ -216,6 +223,8 @@ class ListPage:
     limit: int
     #: int: Total number of objects matching the API call criteria
     total: int
+    #: bool: Whether the listing is descending or not
+    desc: bool
 
     def __init__(self, data: Dict) -> None:
         """Initialize a ListPage instance from the API response data."""
@@ -224,3 +233,4 @@ class ListPage:
         self.limit = data['limit'] if 'limit' in data else 0
         self.count = data['count'] if 'count' in data else len(self.items)
         self.total = data['total'] if 'total' in data else self.offset + self.count
+        self.desc = data['desc'] if 'desc' in data else False
